==> clanlib-4.1.0.tar.gz: ClanLib-4.1.0/Sources/GL/GL1/gl1_transfer_buffer_provider.h <==
/*
**  ClanLib SDK
**  Copyright (c) 1997-2020 The ClanLib Team
**
**  This software is provided 'as-is', without any express or implied
**  warranty.  In no event will the authors be held liable for any damages
**  arising from the use of this software.
**
**  Permission is granted to anyone to use this software for any purpose,
**  including commercial applications, and to alter it and redistribute it
**  freely, subject to the following restrictions:
**
**  1. The origin of this software must not be misrepresented; you must not
**     claim that you wrote the original software. If you use this software
**     in a product, an acknowledgment in the product documentation would be
**     appreciated but is not required.
**  2. Altered source versions must be plainly marked as such, and must not be
**     misrepresented as being the original software.
**  3. This notice may not be removed or altered from any source distribution.
**
**  Note: Some of the libraries ClanLib may link to may have additional
**  requirements or restrictions.
**
**  File Author(s):
**
**    Magnus Norddahl
**    Mark Page
*/

#pragma once

#include "API/Display/TargetProviders/transfer_buffer_provider.h"
#include "API/Core/System/disposable_object.h"

namespace clan
{
	class GL1TransferBufferProvider : public TransferBufferProvider
	{
	public:
		GL1TransferBufferProvider();
		~GL1TransferBufferProvider();
		void create(int size, BufferUsage usage) override;
		void create(void *data, int size, BufferUsage usage) override;

		void *get_data() override { return data; }

		void lock(GraphicContext &gc, BufferAccess access) override {}
		void unlock() override {}
		void upload_data(GraphicContext &gc, int offset, const void *data, int size) override;

	private:
		char *data;
		int size;
	};
}

==> clanlib-4.2.0.tar.gz: ClanLib-4.2.0/Sources/GL/GL1/gl1_transfer_buffer_provider.h <==
/*
**  ClanLib SDK
**  Copyright (c) 1997-2020 The ClanLib Team
**
**  This software is provided 'as-is', without any express or implied
**  warranty.  In no event will the authors be held liable for any damages
**  arising from the use of this software.
**
**  Permission is granted to anyone to use this software for any purpose,
**  including commercial applications, and to alter it and redistribute it
**  freely, subject to the following restrictions:
**
**  1. The origin of this software must not be misrepresented; you must not
**     claim that you wrote the original software. If you use this software
**     in a product, an acknowledgment in the product documentation would be
**     appreciated but is not required.
**  2. Altered source versions must be plainly marked as such, and must not be
**     misrepresented as being the original software.
**  3. This notice may not be removed or altered from any source distribution.
**
**  Note: Some of the libraries ClanLib may link to may have additional
**  requirements or restrictions.
**
**  File Author(s):
**
**    Magnus Norddahl
**    Mark Page
*/

#pragma once

#include "API/Display/TargetProviders/transfer_buffer_provider.h"
#include "API/Core/System/disposable_object.h"

namespace clan
{
	class GL1TransferBufferProvider : public TransferBufferProvider
	{
	public:
		GL1TransferBufferProvider();
		~GL1TransferBufferProvider() override;
		void create(int size, BufferUsage usage) override;
		void create(void *data, int size, BufferUsage usage) override;

		void *get_data() override { return data; }

		void lock(GraphicContext &gc, BufferAccess access) override {}
		void unlock() override {}
		void upload_data(GraphicContext &gc, int offset, const void *data, int size) override;

	private:
		char *data;
		int size;
	};
}
